@@ -1,5 +1,5 @@
 package Koha::Contrib::Mirabel;
-$Koha::Contrib::Mirabel::VERSION = '0.0.5';
+$Koha::Contrib::Mirabel::VERSION = '0.0.6';
 # ABSTRACT: Synchronise un catalogue Koha avec Mir@bel
 use Moose;
 
@@ -11,11 +11,19 @@ use YAML qw/LoadFile Dump/;
 use XML::Simple;
 use LWP::Simple;
 use DateTime;
+use Koha::Contrib::Tamil::Koha;
 use C4::Biblio;
 use MARC::Moose::Record;
 use MARC::Moose::Field::Std;
 
 
+has koha => (
+    is => 'rw',
+    isa => 'Koha::Contrib::Tamil::Koha',
+    default => sub { Koha::Contrib::Tamil::Koha->new() },
+);
+
+
 has url => (
     is => 'rw',
     isa => 'Str',
@@ -57,13 +65,13 @@ sub update {
 
     say '_' x 40, " #$biblionumber" if $self->verbose;
 
-    my $record = GetMarcBiblio($biblionumber);
+    my $record = $self->koha->get_biblio($biblionumber);
     unless ($record) {
         say 'ERREUR: Notice présente dans Mir@bel mais supprimée du Catalogue Koha'
             if $self->verbose;
         return;
     }
-    $record = MARC::Moose::Record::new_from($record, 'Legacy');
+    #$record = MARC::Moose::Record::new_from($record, 'Legacy');
     print $record->as('Text') if $self->verbose;
 
     # On supprime de la notice biblio les champs cibles existants
@@ -238,7 +246,7 @@ Koha::Contrib::Mirabel - Synchronise un catalogue Koha avec Mir@bel
 
 =head1 VERSION
 
-version 0.0.5
+version 0.0.6
 
 =head1 ATTRIBUTES
 
@@ -287,7 +295,7 @@ Frédéric Demians <f.demians@tamil.fr>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Frédéric Demians.
+This software is copyright (c) 2018 by Frédéric Demians.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
